package com.winhc.bigdata.spark.ng.monitor

import com.alibaba.fastjson.JSON
import com.winhc.bigdata.spark.utils.BaseUtil
import org.apache.commons.lang3.StringUtils
import org.apache.spark.internal.Logging

import scala.annotation.meta.{getter, setter}
import scala.collection.mutable

/**
 * @Author: π
 * @Date: 2021/9/9
 * @Description: 企业财产监控v8版本
 */
trait CompanyMonitorHandleV2 extends Logging {

  @getter
  @setter
  protected val is_inc: Boolean //false 为存量

  /**
   * 变更时间
   *
   * @param new_map
   * @return
   */
  protected def get_change_time(bizDate: String, new_map: Map[String, String]): String = {
    var res = bizDate
    if (bizDate.length == 10) {
      res = res.concat(" 00:00:00")
    }
    res
  }

  /**
   * 业务id
   *
   * @param rowkey
   * @return
   */
  protected def get_biz_id(rowkey: String, new_map: Map[String, String]): String = rowkey

  /**
   * 条件过滤
   *
   * @return
   */
  def get_conditional_filter(): String = ""


  protected def get_money(new_map: Map[String, String]): Double = 0D

  protected def processMoney(amt: String): String = {
    var amtstr = amt
    if (amtstr == null) {
      "0"
    } else {
      amtstr = amtstr.replaceAll("[^\\d.]", "")
      if (amtstr.equals("") || amtstr.split("\\.").length > 2 || amtstr.startsWith(".") || amtstr.endsWith(".")) {
        amtstr = "0"
      }
      try {
        amtstr.toDouble
      } catch {
        case ex: Exception => {
          amtstr = "0"
        }
      }
      amtstr
    }
  }

  protected def get_deleted(new_map: Map[String, String], key: String = "deleted"): String = {
    if (new_map == null) return "-1"
    val deleted = new_map.getOrElse(key, "-1")
    deleted
  }

  def filter: (String, String, Seq[String], Map[String, String], Map[String, String]) => Boolean = CompanyMonitorUtils.default_filter

  def flat_map: (ChangeExtract) => Seq[CompanyMonitorRecord]


  protected def getCompanyMonitorRecord(change_extract: ChangeExtract
                                        , entity_info: Seq[EntityInfo]
                                       ): CompanyMonitorRecord = {
    val tn = change_extract.tn
    val update_type = change_extract.update_type
    val old_data = change_extract.old_data
    val new_data = change_extract.new_data
    val biz_date = change_extract.biz_date
    val rowkey = change_extract.rowkey
    val update_time = change_extract.update_time
    //val date = if (is_inc) update_time else biz_date
    if(entity_info.isEmpty){
      CompanyMonitorRecord(
        //todo 待验证
        id = CompanyMonitorUtils.generateId(rowkey, biz_date, tn)
        , entity_info = entity_info
        , dimension_type = ""
        , flow_type = ""
        , rta_desc = ""
        , change_time = biz_date
        , biz_id = rowkey
        , info_risk_level = ""
        , `type` = ""
        , create_time = update_time
        , amt = get_money(new_data)
        , update_type = update_type
        , deleted = get_deleted(new_data)
      )
    }else{
      val type_id = entity_info.map(_.type_id).head
      val args = CompanyMonitorMappings.get_args(`type_id`)
      CompanyMonitorRecord(
        //todo 待验证
        id = CompanyMonitorUtils.generateId(rowkey, biz_date, tn)
        , entity_info = entity_info
        , dimension_type = args.dimension_type
        , flow_type = args.flow_type
        , rta_desc = ""
        , change_time = biz_date
        , biz_id = rowkey
        , info_risk_level = args.info_risk_level
        , `type` = type_id
        , create_time = update_time
        , amt = get_money(new_data)
        , update_type = update_type
        , deleted = get_deleted(new_data)
      )
    }

  }


  protected def getEntity(json: String, id_key: String, name_key: String, type_id: String
                         ): Seq[EntityInfo] = {
    if (StringUtils.isEmpty(json)) {
      Seq.empty
    } else {
      val array = JSON.parseArray(json)
      var list: mutable.Seq[EntityInfo] = mutable.Seq.empty
      for (i <- 0 until array.size()) {
        val jSONObject = array.getJSONObject(i)
        val keyno = jSONObject.getString(id_key)
        val name = jSONObject.getString(name_key)
        list = list :+ EntityInfo(keyno = keyno, name = name, type_id = type_id)
      }
      list
    }
  }



}