package com.winhc.bigdata.spark.ng.monitor

import cn.hutool.crypto.SecureUtil
import com.winhc.bigdata.spark.implicits.CaseClass2JsonHelper._
import org.apache.commons.lang3.StringUtils
import org.apache.spark.sql.Row

/**
 * @author: π
 * @date: 2021/9/10 13:49
 */
case class ChangeExtract(rowkey: String
                         , company_id: String
                         , company_name: String
                         , tn: String
                         , update_type: String
                         , old_data: Map[String, String]
                         , new_data: Map[String, String]
                         , change_fields: Seq[String]
                         , biz_date: String
                         , update_time: String
                        )


case class EntityInfo(keyno: String
                      , name: String
                      , type_id: String
                     ) extends Comparable[EntityInfo] {


  override def hashCode(): Int = s"$name".hashCode()

  override def equals(obj: Any): Boolean =
    obj match {
      case d: EntityInfo =>
        s"$name".equals(s"${d.name}")
      case _ =>
        false
    }

  override def compareTo(o: EntityInfo): Int = s"$name".compareTo(s"${o.name}")
}

case class RowkeyInfo(rowkey: String, tn: String) {
  def toStr(): String = {
    s"$tn@@$rowkey"
  }
}


case class CompanyMonitorRecord(id: String,
                                entity_info: Seq[EntityInfo],
                                dimension_type: String,
                                flow_type: String,
                                rta_desc: String,
                                change_time: String,
                                biz_id: String,
                                info_risk_level: String,
                                `type`: String,
                                create_time: String,
                                amt: Double,
                                update_type: String,
                                deleted: String
                               ) {

  def format(): CompanyMonitorRecord = {
    if (id == null) {
      return null
    }
    if (entity_info == null || entity_info.isEmpty) {
      return null
    }
    //剔除id为空的数据
    val rec = entity_info.filter(r => StringUtils.isNotEmpty(r.keyno))
    if (rec.isEmpty) return null

    if (rec.length != entity_info.length)
      return CompanyMonitorRecord(id,
        rec,
        dimension_type,
        flow_type,
        rta_desc,
        change_time,
        biz_id,
        info_risk_level,
        `type`,
        create_time,
        amt,
        update_type,
        deleted
      )
    this
  }

  def to_row(): Row = {
    Row(SecureUtil.md5(id)
      , entity_info.toJson()
      , dimension_type
      , flow_type
      , rta_desc
      , change_time
      , biz_id
      , info_risk_level
      , `type`
      , create_time
      , amt
      , update_type
      , deleted
    )
  }
}


