package com.winhc.bigdata.spark.ng.monitor.table

import com.winhc.bigdata.spark.ng.monitor.{AbstractDailyHandle, ChangeExtract, CompanyMonitorMappings, CompanyMonitorRecord, CompanyMonitorUtils, EntityInfo}
import com.winhc.bigdata.spark.implicits.MapHelper._
import com.winhc.bigdata.spark.utils.BaseUtil

import scala.collection.mutable

/**
 * @Date: 2020/8/12 18:50
 * @Description: 出质了持有股权(非历史忽略)
 *               出质的股权变更为无效
 */
case class company_equity_info(is_inc: Boolean) extends AbstractDailyHandle {

  override protected def get_money(new_map: Map[String, String]): Double = {
    BaseUtil.amt_div(processMoney(new_map("equity_amount")),"1")
  }

  override def getEntityInfo(new_data: Map[String, String]): Seq[EntityInfo] = {
    Seq.empty[EntityInfo]
  }

  override def flat_map: (ChangeExtract) => Seq[CompanyMonitorRecord] = (change_extract: ChangeExtract) => {
    var list: mutable.Seq[CompanyMonitorRecord] = mutable.Seq.empty

    val tn = change_extract.tn
    val update_type = change_extract.update_type
    val new_data = change_extract.new_data
    val biz_date = change_extract.biz_date
    val rowkey = change_extract.rowkey
    val update_time = change_extract.update_time
    val change_fields = change_extract.change_fields

    //出质了持有股权(非历史忽略)
    val `type1` = "8"
    val args1 = CompanyMonitorMappings.get_args(`type1`)
    list = list :+ CompanyMonitorRecord(
      id = CompanyMonitorUtils.generateId(rowkey, biz_date, tn, `type1`)
      , entity_info = getEntity(new_data.getOrEmptyStr("pledgor_info"), "pledgor_id", "pledgor",type_id=`type1`)
      , dimension_type = args1.dimension_type
      , flow_type = args1.flow_type
      , rta_desc = ""
      , change_time = biz_date
      , biz_id = rowkey
      , info_risk_level = args1.info_risk_level
      , `type` = `type1`
      , create_time = update_time
      , amt = get_money(new_data)
      , update_type = update_type
      , deleted = get_deleted(new_data)
    )

    //出质的股权变更为无效
    if (new_data.getOrEmptyStr("state").equals("无效")) {
      val `type2` = "33"
      val args2 = CompanyMonitorMappings.get_args(`type2`)
      list = list :+ CompanyMonitorRecord(
        id = CompanyMonitorUtils.generateId(rowkey, biz_date, tn, `type2`)
        , entity_info = getEntity(new_data.getOrEmptyStr("pledgor_info"), "pledgor_id", "pledgor",type_id=`type2`)
        , dimension_type = args2.dimension_type
        , flow_type = args2.flow_type
        , rta_desc = ""
        , change_time = biz_date
        , biz_id = rowkey
        , info_risk_level = args2.info_risk_level
        , `type` = `type2`
        , create_time = update_time
        , amt = get_money(new_data)
        , update_type = update_type
        , deleted = get_deleted(new_data)
      )
    }


    list
  }
}
