package com.winhc.bigdata.spark.ng.monitor.table

import com.winhc.bigdata.spark.ng.monitor.{AbstractDailyHandle, ChangeExtract, CompanyMonitorMappings, CompanyMonitorRecord, CompanyMonitorUtils, EntityInfo}
import com.winhc.bigdata.spark.utils.BaseUtil
import com.winhc.bigdata.spark.implicits.MapHelper._
import org.apache.commons.lang3.StringUtils

import scala.collection.mutable

/**
 * @Date: 2020/8/12 18:50
 * @Description: 新增了股东
 *               新增对外投资
 *               投资的公司，所占股份下降
 */
case class company_holder(is_inc: Boolean) extends AbstractDailyHandle {

  override protected def get_money(new_map: Map[String, String]): Double = {
    BaseUtil.amt_div(processMoney(new_map("amount")), "1")
  }

  override def getEntityInfo(new_data: Map[String, String]): Seq[EntityInfo] = {
    Seq.empty[EntityInfo]
  }

  override def flat_map: (ChangeExtract) => Seq[CompanyMonitorRecord] = (change_extract: ChangeExtract) => {
    var list: mutable.Seq[CompanyMonitorRecord] = mutable.Seq.empty

    val tn = change_extract.tn
    val update_type = change_extract.update_type
    val new_data = change_extract.new_data
    val old_data = change_extract.old_data
    val biz_date = change_extract.biz_date
    val rowkey = change_extract.rowkey
    val update_time = change_extract.update_time
    val change_fields = change_extract.change_fields

    //新增了股东
    val `type1` = "10"
    val args1 = CompanyMonitorMappings.get_args(`type1`)
    list = list :+ CompanyMonitorRecord(
      id = CompanyMonitorUtils.generateId(rowkey, biz_date, tn, `type1`)
      , entity_info = Seq(EntityInfo(keyno = new_data.getOrEmptyStr("company_id"), name = new_data.getOrEmptyStr("company_name"), type_id = `type1`))
      , dimension_type = args1.dimension_type
      , flow_type = args1.flow_type
      , rta_desc = ""
      , change_time = CompanyMonitorUtils.formatDate(biz_date)
      , biz_id = rowkey
      , info_risk_level = args1.info_risk_level
      , `type` = `type1`
      , create_time = CompanyMonitorUtils.formatDate(update_time)
      , amt = get_money(new_data)
      , update_type = update_type
      , deleted = get_deleted(new_data)
    )

    //新增对外投资
    val `type2` = "11"
    val args2 = CompanyMonitorMappings.get_args(`type2`)
    list = list :+ CompanyMonitorRecord(
      id = CompanyMonitorUtils.generateId(rowkey, biz_date, tn, `type2`)
      , entity_info = Seq(EntityInfo(keyno = new_data.getOrEmptyStr("holder_id"), name = new_data.getOrEmptyStr("holder_name"), type_id = `type2`))
      , dimension_type = args2.dimension_type
      , flow_type = args2.flow_type
      , rta_desc = ""
      , change_time = CompanyMonitorUtils.formatDate(biz_date)
      , biz_id = rowkey
      , info_risk_level = args2.info_risk_level
      , `type` = `type2`
      , create_time = CompanyMonitorUtils.formatDate(update_time)
      , amt = get_money(new_data)
      , update_type = update_type
      , deleted = get_deleted(new_data)
    )

    //投资的公司，所占股份下降
    if (new_data != null && old_data != null) {
      val new_percent = new_data.getOrEmptyStr("percent")
      val old_percent = old_data.getOrEmptyStr("percent")
      if (change_fields != null && change_fields.contains("percent") && StringUtils.isNotBlank(new_percent) && StringUtils.isNotBlank(old_percent) && new_percent.toDouble < old_percent.toDouble) {
        val `type3` = "34"
        val args3 = CompanyMonitorMappings.get_args(`type3`)
        list = list :+ CompanyMonitorRecord(
          id = CompanyMonitorUtils.generateId(rowkey, biz_date, tn, `type3`)
          , entity_info = Seq(EntityInfo(keyno = new_data.getOrEmptyStr("holder_id"), name = new_data.getOrEmptyStr("holder_name"), type_id = `type3`))
          , dimension_type = args3.dimension_type
          , flow_type = args3.flow_type
          , rta_desc = ""
          , change_time = CompanyMonitorUtils.formatDate(biz_date)
          , biz_id = rowkey
          , info_risk_level = args3.info_risk_level
          , `type` = `type3`
          , create_time = CompanyMonitorUtils.formatDate(update_time)
          , amt = get_money(new_data)
          , update_type = update_type
          , deleted = get_deleted(new_data)
        )
      }
    }
    list
  }
}


