package com.winhc.bigdata.spark.ng.monitor.table

import com.winhc.bigdata.spark.ng.monitor.{AbstractDailyHandle, ChangeExtract, CompanyMonitorMappings, CompanyMonitorRecord, CompanyMonitorUtils, EntityInfo}
import com.winhc.bigdata.spark.implicits.MapHelper._
import com.winhc.bigdata.spark.utils.BaseUtil

import scala.collection.mutable

/**
 * @Date: 2020/8/12 18:50
 * @Description: 抵押了公司土地-抵押人
 *               接受了他人土地抵押-抵押权人
 */
case class company_land_mortgage(is_inc: Boolean) extends AbstractDailyHandle {

  override protected def get_money(new_map: Map[String, String]): Double = {
    BaseUtil.amt_div(processMoney(new_map("mortgage_amount")), "1")
  }

  override def getEntityInfo(new_data: Map[String, String]): Seq[EntityInfo] = {
    Seq.empty[EntityInfo]
  }

  override def flat_map: (ChangeExtract) => Seq[CompanyMonitorRecord] = (change_extract: ChangeExtract) => {
    var list: mutable.Seq[CompanyMonitorRecord] = mutable.Seq.empty

    val tn = change_extract.tn
    val update_type = change_extract.update_type
    val new_data = change_extract.new_data
    val biz_date = change_extract.biz_date
    val rowkey = change_extract.rowkey
    val update_time = change_extract.update_time

    //抵押了公司土地
    val `type1` = "13"
    val args1 = CompanyMonitorMappings.get_args(`type1`)
    list = list :+ CompanyMonitorRecord(
      id = CompanyMonitorUtils.generateId(rowkey, biz_date, tn, `type1`)
      , entity_info = Seq(EntityInfo(keyno = new_data.getOrEmptyStr("mortgagor_company_id"), name = new_data.getOrEmptyStr("mortgagor"), type_id = `type1`))
      , dimension_type = args1.dimension_type
      , flow_type = args1.flow_type
      , rta_desc = ""
      , change_time = biz_date
      , biz_id = rowkey
      , info_risk_level = args1.info_risk_level
      , `type` = `type1`
      , create_time = update_time
      , amt = get_money(new_data)
      , update_type = update_type
      , deleted = get_deleted(new_data)
    )
    val `type2` = "21"
    val args2 = CompanyMonitorMappings.get_args(`type2`)
    //接受了他人土地抵押
    list = list :+ CompanyMonitorRecord(
      id = CompanyMonitorUtils.generateId(rowkey, biz_date, tn, `type2`)
      , entity_info = Seq(EntityInfo(keyno = new_data.getOrEmptyStr("mortgagee_company_id"), name = new_data.getOrEmptyStr("mortgagee"), type_id = `type2`))
      , dimension_type = args2.dimension_type
      , flow_type = args2.flow_type
      , rta_desc = ""
      , change_time = biz_date
      , biz_id = rowkey
      , info_risk_level = args2.info_risk_level
      , `type` = `type2`
      , create_time = update_time
      , amt = get_money(new_data)
      , update_type = update_type
      , deleted = get_deleted(new_data)
    )
    list
  }
}
