package com.winhc.bigdata.spark.ng.monitor.table

import com.winhc.bigdata.spark.ng.monitor.{AbstractDailyHandle, ChangeExtract, CompanyMonitorMappings, CompanyMonitorRecord, CompanyMonitorUtils, EntityInfo}
import com.winhc.bigdata.spark.utils.BaseUtil
import com.winhc.bigdata.spark.implicits.MapHelper._

import scala.collection.mutable

/**
 * @Date: 2020/9/13 11:44
 * @Description: 新增胜诉案件(原告) | AND data['is_success'] = '胜'  AND data['case_stage']= '一审'  AND  data['case_type'] = '民事案件' AND  data['name_type'] = 'y'
 *               有恢复执行案件(被告) | AND  data['case_no'] like concat('%','恢','%')
 *               新增财产保全案件(被告) | AND  data['case_no'] like concat('%','恢','%')
 */
case class wenshu_detail_v2(is_inc: Boolean) extends AbstractDailyHandle {


  override protected def get_money(new_map: Map[String, String]): Double = {
    BaseUtil.amt_div(processMoney(new_map("judge_amt")), "1")
  }

  override def getEntityInfo(new_data: Map[String, String]): Seq[EntityInfo] = {
    Seq.empty[EntityInfo]
  }

  override def flat_map: (ChangeExtract) => Seq[CompanyMonitorRecord] = (change_extract: ChangeExtract) => {
    var list: mutable.Seq[CompanyMonitorRecord] = mutable.Seq.empty

    val tn = change_extract.tn
    val update_type = change_extract.update_type
    val new_data = change_extract.new_data
    val biz_date = change_extract.biz_date
    val rowkey = change_extract.rowkey
    val update_time = change_extract.update_time

    if (new_data.getOrEmptyStr("is_success").equals("胜")
      && new_data.getOrEmptyStr("case_stage").equals("一审")
      && new_data.getOrEmptyStr("case_type").equals("民事案件")) {
      //新增胜诉案件
      val `type` = "20"
      val args1 = CompanyMonitorMappings.get_args(`type`)
      list = list :+ CompanyMonitorRecord(
        id = CompanyMonitorUtils.generateId(rowkey, biz_date, tn, `type`)
        , entity_info = getEntity(new_data.getOrEmptyStr("plaintiff_info"), "litigant_id", "name",type_id = `type`)
        , dimension_type = args1.dimension_type
        , flow_type = args1.flow_type
        , rta_desc = ""
        , change_time = biz_date
        , biz_id = rowkey
        , info_risk_level = args1.info_risk_level
        , `type` = `type`
        , create_time = update_time
        , amt = get_money(new_data)
        , update_type = update_type
        , deleted = get_deleted(new_data)
      )
    } else if (new_data.getOrEmptyStr("case_no").contains("恢")) {
      val `type` = "19"
      val args2 = CompanyMonitorMappings.get_args(`type`)
      //有恢复执行案件
      list = list :+ CompanyMonitorRecord(
        id = CompanyMonitorUtils.generateId(rowkey, biz_date, tn, `type`)
        , entity_info = getEntity(new_data.getOrEmptyStr("defendant_info"), "litigant_id", "name",type_id = `type`)
        , dimension_type = args2.dimension_type
        , flow_type = args2.flow_type
        , rta_desc = ""
        , change_time = biz_date
        , biz_id = rowkey
        , info_risk_level = args2.info_risk_level
        , `type` = `type`
        , create_time = update_time
        , amt = get_money(new_data)
        , update_type = update_type
        , deleted = get_deleted(new_data)
      )
    } else if (new_data.getOrEmptyStr("case_no").contains("保")) {
      val `type` = "27"
      val args3 = CompanyMonitorMappings.get_args(`type`)
      //新增财产保全案件
      list = list :+ CompanyMonitorRecord(
        id = CompanyMonitorUtils.generateId(rowkey, biz_date, tn, `type`)
        , entity_info = getEntity(new_data.getOrEmptyStr("defendant_info"), "litigant_id", "name",type_id = `type`)
        , dimension_type = args3.dimension_type
        , flow_type = args3.flow_type
        , rta_desc = ""
        , change_time = biz_date
        , biz_id = rowkey
        , info_risk_level = args3.info_risk_level
        , `type` = `type`
        , create_time = update_time
        , amt = get_money(new_data)
        , update_type = update_type
        , deleted = get_deleted(new_data)
      )
    }
    list
  }
}
